@@ -1,5 +1,9 @@
 import sqlite3
-from netoprmgr.templates.show_env.env_WS_C3850_12S import env_WS_C3850_12S
+from netoprmgr.templates.show_env.env_C3850 import env_C3850
+from netoprmgr.templates.show_env.env_C2960 import env_C2960
+from netoprmgr.templates.show_env.env_C9200L import env_C9200L
+from netoprmgr.templates.show_env.env_C9300 import env_C9300
+from netoprmgr.templates.show_env.env_C4507R import env_C4507R
 class get_env:
     def __init__(self,files):
         self.files=files
@@ -28,17 +32,28 @@ class get_env:
 
         for file in self.files:
             try:
+                print('Processing File :')
+                print(file)
                 read_file = open(file, 'r')
                 read_file_list = read_file.readlines()
                 #len(read_file_list)
                 for i in read_file_list:
-                    if 'env-WS-C3850-12S' in i:
-                        try:
-                            env_WS_C3850_12S(file)
-                        #except NameError:
-                            #raise
-                        except:
-                            pass
+                    if 'C3850' in i:
+                        env_C3850(file)
+                        break
+                    elif 'C2960' in i:
+                        env_C2960(file)
+                        break
+                    elif 'C9200L' in i:
+                        env_C9200L(file)
+                        break
+                    elif 'C9300' in i:
+                        env_C9300(file)
+                        break
+                    elif 'C4507R' in i:
+                        env_C4507R(file)
+                        break
+
             #except NameError:
             # raise
             except:
